/* Yo Emacs, this -*- C++ -*-

  Copyright (C) 1999-2001 Jens Hoefkens
  jens@hoefkens.com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
*/


#ifndef __KBG_VERSION_H
#define __KBG_VERSION_H


#define PROG_NAME      "kbackgammon"
#define PROG_VERSION   "2.5.0"
#define PROG_HOME      "http://www.hoefkens.com/lnx/kbg.html"

#define PROG_COOKIE    10500   // see also kdebug.areas

#endif // __KBG_VERSION_H
